#
# spec file for package klatexformula
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libversion 4
%define libversionpkgsuffix 4
Name:           klatexformula
Version:        4.1.0
Release:        1.17
Summary:        A gaphical application for generating images from LaTeX equations
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Frontends
URL:            http://klatexformula.sourceforge.net/
Source0:        http://download.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-compilation-error-with-Qt-5.15.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  graphviz-gd
BuildRequires:  gs
BuildRequires:  help2man
BuildRequires:  hicolor-icon-theme
BuildRequires:  libstdc++-devel
BuildRequires:  shared-mime-info
BuildRequires:  texlive-latex
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Core) >= 5.12.7
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Designer)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  cmake(Qt5Xml)
Requires:       libklfbackend%{libversionpkgsuffix} = %{version}
Requires:       libklftools%{libversionpkgsuffix} = %{version}
Requires:       shared-mime-info
Obsoletes:      KLatexFormula < 3.2
Obsoletes:      klatexformula-plugins < 3.2.2
Provides:       KLatexFormula = %{version}
Provides:       klatexformula-plugins = %{version}

%description
KLatexFormula is a graphical user interface for generating images
from LaTeX equations. These images can be dragged and dropped or copied and
pasted into external applications (presentations, text documents, graphics...),
or can be saved to disk in a variety of formats (PNG, JPG, BMP, EPS, PDF, etc.).

If the "cm-unicode" LaTeX package is installed, KLatexFormula can use LaTeX's
Computer Modern Sans Serif font as a default application font.

%package -n libklfbackend%{libversionpkgsuffix}
Summary:        KLatexFormula backend library (Qt4)
Group:          Development/Libraries/C and C++
Requires:       gs
Requires:       texlive-latex
Provides:       libklfbackend = %{version}

%description -n libklfbackend%{libversionpkgsuffix}
A C++/Qt library to generate images (PNG, EPS, PDF, plus all Qt-supported image
formats) from LaTeX equations.

This library implements the base functionality of KLatexFormula. This library
is compiled for Qt 4.

See also packages klatexformula and libklfbackend-qt3.

%package -n klfbackend-devel
Summary:        Development files for the KLatexFormula backend library
Group:          Development/Libraries/C and C++
Requires:       libklfbackend = %{version}
Provides:       libklfbackend-devel = %{version}
Obsoletes:      libklfbackend-devel < 4.0.0

%description -n klfbackend-devel
A C++/Qt library to generate images (PNG, EPS, PDF, plus all Qt-supported image
formats) from LaTeX equations.

This library implements the base functionality of KLatexFormula.

This package contains the needed files for development.

See also packages klatexformula-devel and libklfbackend-qt3-devel

%package -n libklftools%{libversionpkgsuffix}
Summary:        KLatexFormula tool library
Group:          Development/Libraries/C and C++
Provides:       libklftools = %{version}

%description -n libklftools%{libversionpkgsuffix}
A C++/Qt4 library containing general-purpose GUI tools.

These tools were originially written for use by klatexformula, but they have
been promoted to a library for use in any application.

%package -n klftools-devel
Summary:        Development files for the KLatexFormula tool library
Group:          Development/Libraries/C and C++
Requires:       libklftools = %{version}
Obsoletes:      %{name}-devel < 4.0.0
Provides:       %{name}-devel = %{version}
Obsoletes:      libklftools-devel < 4.0.0
Provides:       libklftools-devel = %{version}

%description -n klftools-devel
A C++/Qt4 library containing general-purpose GUI tools.

These tools were originially written for use by klatexformula, but they have
been promoted to a library for use in any application.

This package contains the needed files for development.

%package apidoc
Summary:        API documentation for KLatexFormula
Group:          Documentation/HTML
Requires:       klatexformula = %{version}
BuildArch:      noarch

%description apidoc
KLatexFormula is a graphical user interface for generating images
from LaTeX equations.

This package contains the API documentation of the libraries libklfbackend and
libklftool which are the different components of klatexformula.

%prep
%autosetup -p1

%build
%cmake \
       -DKLF_CMAKE_DEBUG=ON \
       -DKLF_INCLUDE_FONTS="" \
       -DKLF_INSTALL_APIDOC_DIR="share/doc/klatexformula-api" \
       -DKLF_INSTALL_BIN_DIR=%{_bindir} \
       -DKLF_INSTALL_DESKTOP_CATEGORIES="Qt;Office;Utility;Viewer;DesktopUtility;" \
       -DKLF_INSTALL_DESKTOP_ICON="klatexformula" \
       -DKLF_INSTALL_DEVEL=OFF \
       -DKLF_INSTALL_ICON_THEME="share/icons/hicolor" \
       -DKLF_INSTALL_KLFBACKEND_AUTO_HEADERS=ON \
       -DKLF_INSTALL_KLFBACKEND_HEADERS=ON \
       -DKLF_INSTALL_KLFTOOLS_HEADERS=ON \
       -DKLF_INSTALL_LIB_DIR=%{_libdir} \
       -DKLF_INSTALL_RUNTIME=ON \
       -DKLF_INSTALL_SHARE_MAN1_DIR=%{_mandir}/man1 \
       -DKLF_INSTALL_SHARE_PIXMAPS_DIR="" \
       -DKLF_LIBKLFBACKEND_STATIC=OFF \
       -DKLF_LIBKLFTOOLS_STATIC=OFF

%cmake_build

%install
%cmake_install

# Doxygen doc generates some duplicate files in the big lot ...
%fdupes %{buildroot}%{_datadir}/doc/klatexformula-api

# Man pages are duplicates
%fdupes -s %{buildroot}%{_mandir}

%suse_update_desktop_file klatexformula

%post -n libklfbackend%{libversionpkgsuffix} -p /sbin/ldconfig
%postun -n libklfbackend%{libversionpkgsuffix} -p /sbin/ldconfig
%post -n libklftools%{libversionpkgsuffix} -p /sbin/ldconfig
%postun -n libklftools%{libversionpkgsuffix} -p /sbin/ldconfig

%files
%license CMUFONTS_COPYING COPYING.txt
%doc AUTHORS README
%{_bindir}/klatexformula
%{_bindir}/klatexformula_cmdl
%{_datadir}/applications/klatexformula.desktop
%{_datadir}/icons/*/*/*/*
%{_datadir}/klatexformula/
%{_datadir}/mime/packages/klatexformula-mime.xml
%{_mandir}/man1/klatexformula.1%{?ext_man}
%{_mandir}/man1/klatexformula_cmdl.1%{?ext_man}

%files -n libklfbackend%{libversionpkgsuffix}
%{_libdir}/libklfbackend.so.%{libversion}

%files -n klfbackend-devel
%{_includedir}/klfbackend/
%{_libdir}/libklfbackend.so

%files -n libklftools%{libversionpkgsuffix}
%{_libdir}/libklftools.so.*

%files -n klftools-devel
%{_includedir}/klftools/
%{_libdir}/libklftools.so

%files apidoc
%{_datadir}/doc/klatexformula-api

%changelog
* Thu Nov 26 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.1.0:
  * Support for PDF-based and unicode LaTeX engines pdflatex,
    xelatex and lualatex.
  * Ukrainian translation
  * Minor enhancements and bug fixes.
- Spec cleanup
- Drop obsolete patch:
  * klatexformula-4.0.0-include_QAction.patch
- Drop unneeded patch:
  * klatexformula-4.0.0-remove-uninstall-target.patch
- Add upstream patch:
  * 0001-Fix-compilation-error-with-Qt-5.15.patch
* Sun Oct  7 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
- Straighten out some bumpy grammar.
* Sun Oct  7 2018 Luigi Baldoni <aloisio@gmx.com>
- Add klatexformula-4.0.0-include_QAction.patch to fix Qt 5.11
  build
* Wed Jul 19 2017 badshah400@gmail.com
- Update to version 4.0.0:
  * Detailed release notes from
    https://klatexformula.sourceforge.io/doc/rel-notes-v4_0.
- Drop klatexformula-3.2.5-add-needed.patch: No longer needed.
- Rebase klatexformula-3.2.8-remove-uninstall-target.patch, and
  rename to klatexformula-4.0.0-remove-uninstall-target.patch.
- Drop Qt3 bindings, klatexformula only builds with Qt5.
- Ktexteditorplugin is not yet ported to Qt5, turn related
  package off (build_ktexteditorplugin -> 0).
- Update BuildRequires:
  * Replace Qt4 by appropriate Qt5 packages.
  * Introduce hicolor-icon-theme BR to ensure proper permissions
    for the %%{_datadir}/icons/hicolor directory.
  * Drop kdelibs4: KDE libs no longer needed since ktexteditor
    no longer builds (not yet ported to Qt5).
- Rename libklftools-devel and libklfbackend-devel to
  klftools-devel and klfbackend-devel respectively to make
  the devel package names compatible with shared lib packaging
  policy. Add appropriate Obsoletes/Provides for smooth upgrade.
- Drop static libraries everywhere, and ensure header files
  are installed nevertheless (-DKLF_INSTALL_KLF*_HEADERS=ON).
- klfapp is dead, so drop the klatexformula-devel package,
  and Obsolete/Provides it from klftools-devel.
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Sat Mar 12 2016 antoine.belvire@laposte.net
- Fix build on Tumbleweed (CMake error):
  * Add klatexformula-3.2.8-remove-uninstall-target.patch
* Fri Jan 31 2014 badshah400@gmail.com
- Update to version 3.2.8:
  - Fixes a bug caused by recent versions of ghostscript
* Wed Aug  7 2013 badshah400@gmail.com
- Update to version 3.2.7:
  + Fixes a bug preventing epstopdf from being executed on some
    linux systems
- Pass -DCMAKE_SKIP_RPATH=ON to cmake to fix Factory build issues.
* Wed Jun  6 2012 badshah400@gmail.com
- Update to version 3.2.6:
  + Fixes a technical issue when compiling with gcc 4.7
- Rebase klatexformula-3.2.5-add-needed.patch
- Drop patch klatexformula-gcc47.patch: fixed upstream.
* Sat Mar 24 2012 dimstar@opensuse.org
- Add klatexformula-gcc47.patch: Fix build with gcc 4.7.
* Fri Mar 23 2012 phfaist@opensuse.org
- Update to version 3.2.5
* Mon Sep 26 2011 crrodriguez@opensuse.org
- Update to version 3.2.4
  * removed unnecessary explicit -m32/-m64 build flags (should fix broken compilation on some platforms)
  * minor enhancements
- Link to libX11 as well, fixes build with no-add-needed
* Mon Feb  7 2011 phfaist@opensuse.org
- initial package
